import json
import sys

from typing import List

from alibabacloud_swas_open20200601.client import Client as SWAS_OPEN20200601Client
from alibabacloud_tea_openapi import models as open_api_models
from alibabacloud_swas_open20200601 import models as swas__open20200601_models

# Write by lyc at 2021-11-24

class SWAS:
    def __init__(self, key) -> None:
        self.access_key_id = key['access_key_id']
        self.access_key_secret = key['access_key_secret']
        self.region_id = key['region_id']
        # SWAS
        self.image_id = key['SWAS']['image_id']
        self.plan_id = key['SWAS']['plan_id']
        self.instance_name = key['SWAS']['instance_name']
        self.password = key['SWAS']['password']


    @staticmethod
    def create_client(access_key_id: str, access_key_secret: str,) -> SWAS_OPEN20200601Client:
        """
        使用AK&SK初始化账号Client
        @param access_key_id:
        @param access_key_secret:
        @return: Client
        @throws Exception
        """
        config = open_api_models.Config(access_key_id=access_key_id, access_key_secret=access_key_secret)
        config.endpoint = 'swas.cn-hongkong.aliyuncs.com'       # 访问的域名
        return SWAS_OPEN20200601Client(config)


    def listImages(self, image_type='system'):
        """[获取镜像列表]https://next.api.aliyun.com/document/SWAS-OPEN/2020-06-01/ListImages

        Args:
            image_type (str, optional): [镜像类型：system：系统镜像；app：应用镜像；custom：自定义镜像]. Defaults to 'system'.

        Returns:
            [json]: [json response]
        """
        client = SWAS.create_client(self.access_key_id, self.access_key_secret)
        list_images_request = swas__open20200601_models.ListImagesRequest(
            region_id=self.region_id,
            image_type=image_type
        )
        return json.dumps(client.list_images(list_images_request).body.to_map())


    def listPlans(self):
        """[获取套餐信息]https://next.api.aliyun.com/document/SWAS-OPEN/2020-06-01/ListPlans

        Returns:
            [json]: [json response]
        """
        client = SWAS.create_client(self.access_key_id, self.access_key_secret)
        list_plans_request = swas__open20200601_models.ListPlansRequest(
            region_id=self.region_id
        )
        return json.dumps(client.list_plans(list_plans_request).body.to_map())


    def createInstances(self, amount=1):
        """[创建实例]https://next.api.aliyun.com/document/SWAS-OPEN/2020-06-01/CreateInstances

        Args:
            amount (int, optional): [创建轻量应用服务器的数量。取值范围：1~20]. Defaults to 1.

        Returns:
            [json]: [json response]
        """
        client = SWAS.create_client(self.access_key_id, self.access_key_secret)
        create_instances_request = swas__open20200601_models.CreateInstancesRequest(
            region_id=self.region_id,
            image_id=self.image_id,
            plan_id=self.plan_id,
            period=1,
            # auto_renew=True,
            # auto_renew_period=1,
            amount=amount
        )
        return json.dumps(client.create_instances(create_instances_request).body.to_map())


    def updateInstanceAttribute(self, instance_id):
        """[修改实例部分信息]https://next.api.aliyun.com/document/SWAS-OPEN/2020-06-01/UpdateInstanceAttribute

        Args:
            instance_id ([str]): [指定的轻量应用服务器的实例ID]

        Returns:
            [json]: [json response]
        """
        client = SWAS.create_client(self.access_key_id, self.access_key_secret)
        update_instance_attribute_request = swas__open20200601_models.UpdateInstanceAttributeRequest(
            instance_id=instance_id,
            region_id=self.region_id,
            password=self.password,
            instance_name=self.instance_name
        )
        return json.dumps(client.update_instance_attribute(update_instance_attribute_request).body.to_map())


    def stopInstance(self, instance_id):
        """[停止实例]https://next.api.aliyun.com/document/SWAS-OPEN/2020-06-01/StopInstance

        Args:
            instance_id ([str]): [指定的轻量应用服务器的实例ID]

        Returns:
            [json]: [json response]
        """
        client = SWAS.create_client(self.access_key_id, self.access_key_secret)
        stop_instance_request = swas__open20200601_models.StopInstanceRequest(
            instance_id=instance_id,
            region_id=self.region_id
        )
        return json.dumps(client.stop_instance(stop_instance_request).body.to_map())


    def startInstance(self, instance_id):
        """[启动实例]https://next.api.aliyun.com/document/SWAS-OPEN/2020-06-01/StartInstance

        Args:
            instance_id ([str]): [指定的轻量应用服务器的实例ID]

        Returns:
            [json]: [json response]
        """
        client = SWAS.create_client(self.access_key_id, self.access_key_secret)
        start_instance_request = swas__open20200601_models.StartInstanceRequest(
            instance_id=instance_id,
            region_id=self.region_id
        )
        return json.dumps(client.start_instance(start_instance_request).body.to_map())


    def rebootInstance(self, instance_id):
        """[重启实例]https://next.api.aliyun.com/document/SWAS-OPEN/2020-06-01/RebootInstance

        Args:
            instance_id ([str]): [指定的轻量应用服务器的实例ID]

        Returns:
            [json]: [json response]
        """
        client = SWAS.create_client(self.access_key_id, self.access_key_secret)
        reboot_instance_request = swas__open20200601_models.RebootInstanceRequest(
            instance_id=instance_id,
            region_id=self.region_id
        )
        return json.dumps(client.reboot_instance(reboot_instance_request).body.to_map())


    def listInstances(self, instance_ids='', public_ip_addresses=''):
        """[获取实例列表]https://next.api.aliyun.com/document/SWAS-OPEN/2020-06-01/ListInstances

        Args: 两种查询方式二选一
            instance_ids ([list]): [轻量应用服务器的实例ID。取值可以由多个实例ID组成一个JSON数组]
            public_ip_addresses ([list]): [轻量应用服务器的公网IP。取值可以由多个公网ID组成一个JSON数组]

        Returns:
            [json]: [json response]
        """
        client = SWAS.create_client(self.access_key_id, self.access_key_secret)
        if len(instance_ids) > 0:
            list_instances_request = swas__open20200601_models.ListInstancesRequest(
            region_id=self.region_id,
            instance_ids=instance_ids,
            page_size=100
            )
        elif len(public_ip_addresses) > 0:
            list_instances_request = swas__open20200601_models.ListInstancesRequest(
            region_id=self.region_id,
            public_ip_addresses=public_ip_addresses,
            page_size=100
            )
        else:
            list_instances_request = swas__open20200601_models.ListInstancesRequest(
            region_id=self.region_id,
            page_size=100
        )
        return json.dumps(client.list_instances(list_instances_request).body.to_map())


    def listFirewallRules(self, instance_id):
        """[获取实例的防火墙规则]https://next.api.aliyun.com/document/SWAS-OPEN/2020-06-01/ListFirewallRules

        Args:
            instance_id ([str]): [指定的轻量应用服务器的实例ID]

        Returns:
            [json]: [json response]
        """
        client = SWAS.create_client(self.access_key_id, self.access_key_secret)
        list_firewall_rules_request = swas__open20200601_models.ListFirewallRulesRequest(
            instance_id=instance_id,
            region_id=self.region_id
        )
        return json.dumps(client.list_firewall_rules(list_firewall_rules_request).body.to_map())


    def deleteFirewallRule(self, instance_id, rule_id):
        """[删除实例防火墙规则]https://next.api.aliyun.com/document/SWAS-OPEN/2020-06-01/DeleteFirewallRule

        Args:
            instance_id ([str]): [指定的轻量应用服务器的实例ID]
            rule_id ([str]): [防火墙规则ID]

        Returns:
            [json]: [json response]
        """
        client = SWAS.create_client(self.access_key_id, self.access_key_secret)
        delete_firewall_rule_request = swas__open20200601_models.DeleteFirewallRuleRequest(
            instance_id=instance_id,
            region_id=self.region_id,
            rule_id=rule_id
        )
        return json.dumps(client.delete_firewall_rule(delete_firewall_rule_request).body.to_map())


    def createFirewallRule(self, instance_id, port, rule_protocol='TCP', remark=''):
        """[创建实例的防火墙规则]https://next.api.aliyun.com/document/SWAS-OPEN/2020-06-01/CreateFirewallRule

        Args:
            instance_id ([str]): [指定的轻量应用服务器的实例ID]
            port ([str]): [端口或端口范围3306或1/65535]
            rule_protocol ([str]): [传输层协议。取值范围：(TCP|UDP|TcpAndUdp)]. Defaults to 'TCP'.
            remark (str, optional): [防火墙规则的备注]. Defaults to ''.

        Returns:
            [json]: [json response]
        """
        client = SWAS.create_client(self.access_key_id, self.access_key_secret)
        create_firewall_rule_request = swas__open20200601_models.CreateFirewallRuleRequest(
            instance_id=instance_id,
            region_id=self.region_id,
            rule_protocol=rule_protocol,
            port=port,
            remark=remark
        )
        return json.dumps(client.create_firewall_rule(create_firewall_rule_request).body.to_map())


    def renewInstance(self, instance_id, period=1):
        """[续费实例]https://next.api.aliyun.com/document/SWAS-OPEN/2020-06-01/RenewInstance

        Args:
            instance_id ([str]): [指定的轻量应用服务器的实例ID]
            period ([int]): [续费时长。单位：月。取值范围：{"1", "3", "6","12", "24", "36"}]. Defaults to '1'.

        Returns:
            [json]: [json response]
        """
        client = SWAS.create_client(self.access_key_id, self.access_key_secret)
        renew_instance_request = swas__open20200601_models.RenewInstanceRequest(
            instance_id=instance_id,
            region_id=self.region_id,
            period=period
        )
        return json.dumps(client.renew_instance(renew_instance_request).body.to_map())


    def resetSystem(self, instance_id, image_id=''):
        """[重置系统]https://next.api.aliyun.com/document/SWAS-OPEN/2020-06-01/ResetSystem

        Args:
            instance_id ([str]): [指定的轻量应用服务器的实例ID]
            image_id ([str]): [目标镜像ID。如果不输入目标镜像ID，默认为重置当前镜像。]

        Returns:
            [json]: [json response]
        """

        client = SWAS.create_client(self.access_key_id, self.access_key_secret)
        if len(image_id) > 0:
            reset_system_request = swas__open20200601_models.ResetSystemRequest(
                instance_id=instance_id,
                region_id=self.region_id,
                image_id=image_id
            )
        else:
            reset_system_request = swas__open20200601_models.ResetSystemRequest(
            instance_id=instance_id,
            region_id=self.region_id
        )
        return json.dumps(client.reset_system(reset_system_request).body.to_map())




import os
import hashlib

# Write by lyc at 2019-8-9
# Modify by lyc at 2020-3-2
# 文件 md5 值操作

def get_smallfile_md5(filename):
    '''获取小文件md5值'''
    try:
        with open(filename,'rb') as f_read:
            md5_obj = hashlib.md5()
            md5_obj.update(f_read.read())
            hash_code = md5_obj.hexdigest()
            md5 = str(hash_code).lower()

        return md5
    
    except Exception as err:
        print(err)


def get_largefile_md5(filename):
    '''获取大文件md5值'''
    try:
        bufsize = 1024 * 8        # 大文件增大读入缓冲区块，按块读取数据
        with open(filename, 'rb') as f_read:
            md5_obj = hashlib.md5()
            while True:
                d = f_read.read(bufsize)
                if not d:
                    break
                md5_obj.update(d)
            hash_code = md5_obj.hexdigest()
            md5 = str(hash_code).lower()

        return md5
    
    except Exception as err:
        print(err)


def get_file_md5(filename):
    """[获取文件md5值（接口方法）]

    Args:
        filename ([string]): [文件的绝对路径]

    Returns:
        [string]: [文件的md5值]
    """
    # 根据文件大小简单判断：
    chunk = 1024 * 1024 * 50        # 50Mb
    if os.path.getsize(filename) <= chunk: 
        filename_md5 = get_smallfile_md5(filename)
    else: 
        filename_md5 = get_largefile_md5(filename)

    return filename_md5

############################################################################################
import requests

def get_remotefile_md5(filename):
    """[获取远端服务上某个指定文件的md5值]

    Args:
        filename ([string]): [文件的绝对路径]

    Returns:
        [string]: [远端文件的md5值]
    """
    url = 'http://checkmd5.tdtech.gao7.com/fileinfo.php?path={}&action=1'.format(filename)
    try:
        response = requests.get(url)
        remotefile_md5 = response.content.decode('utf-8').lower().split(' ')[0]
        return remotefile_md5

    except Exception as err:
        print(err)




import socket

def get_my_ip():
    """[获取本机IP地址]

    Returns:
        [string]: [eth0 IP地址]
    """
    ## 方法一：通过hostname（不推荐）
    # hostname = socket.gethostname()
    # ip = socket.gethostbyname(hostname)
    # return ip

    # 方法二：通过UDP，参考：https://www.cnblogs.com/xxpythonxx/p/11826491.html
    try:
        s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
        s.connect(('114.114.114.114', 80))
        ip = s.getsockname()[0]
    finally:
        s.close()
    return ip

#########################################################################################################
import os
import zipfile

def zip_file(dir, filename):
    """[打包并压缩目录或文件] 
            如果dir是单个文件，只压缩文件；
            如果是目录，获取目录下的所有文件加入列表再打包压缩

    Args:
        dir ([string]): [要被打包的目录的绝对路径]
        filename ([string]): [打包后的文件名xxx.zip]

    Returns:
        [bool]: True-成功；False-失败
    """
    try:
        filelist = []
        if os.path.isfile(dir):
            filelist.append(dir)
        else:
            for root, dirs, files in os.walk(dir):
                for dir in dirs:
                    filelist.append(os.path.join(root,dir))
                for name in files:
                    filelist.append(os.path.join(root, name))

        zf = zipfile.ZipFile(filename, "w", zipfile.zlib.DEFLATED)
        for tar in filelist:
            # arcname = tar[len(dir):]
            # zf.write(tar,arcname)
            zf.write(tar)

        zf.close()
        return True

    except Exception as err:
        print(err)
        return False






import json, requests
import time, datetime
from tools_lyc7456.uCloudapi.signature import verify_ac

# Write by lyc at 2021-12-27


class UDB():
    '''优刻得UDB封装'''
    def __init__(self, key):
        self.PublicKey = key['PublicKey']           # 公钥
        self.PrivateKey = key['PrivateKey']         # 私钥
        self.api_url = key['api_url']               # api接口url
        self.project_id = key['project_id']         # 项目id
        self.region = key['region']                 # 地域
        

    def describeUDBInstance(self, class_type='SQL'):
        """[获取云数据库信息 - DescribeUDBInstance]https://docs.ucloud.cn/api/udb-api/describe_udb_instance
        主要用于获取udb实例id

        Args:
            class_type (str, optional): [DB种类]. 其取值如下：mysql: SQL；mongo: NOSQL；postgresql: postgresql.

        Returns:
            [str]: [response]
        """
        try:
            params = {
                'Action': 'DescribeUDBInstance',            # 接口名称
                'Region': self.region,              # 地区
                'ProjectId': self.project_id,
                'PublicKey': self.PublicKey,
                'ClassType': class_type,
                'Limit': 100,
                'Offset': 0,
            }
            # 签名
            signature = verify_ac(self.PublicKey, self.PrivateKey, params)
            params['Signature'] = signature

            # POST请求接口
            headers = {'Content-Type': 'application/json'}
            response = requests.post(url=self.api_url, headers=headers, data=json.dumps(params))
            resp_string = response.content.decode('utf-8')

            return resp_string

        except Exception as err:
            # print(err)
            return err



    def describeUDBBackup(self, db_id, backup_type='Auto', begin_day=-1):
        """[获取备份列表 - DescribeUDBBackup]https://docs.ucloud.cn/api/udb-api/describe_udb_backup
        主要用于获取指定udb的备份id

        Args:
            db_id (string, optional): [DB实例Id]
            backup_type (string, optional): [备份类型] 默认值'Auto'，可选值 Manual 手动 Auto 自动。
            backup_type (int, optional): [备份类型]. 默认值为0。可选值为0或1，0表示自动，1表示手动。
            begin_day (int, optional): [过滤条件，查询n天前的备份列表] 取值为整型负数。默认值-1，表示昨天，即获取过去的24小时内的备份列表。

        Returns:
            [str]: [response]
        """
        try:
            backup_type_int = 0 if backup_type == 'Auto' else 1         # 类型转换（string->int）backup_type='Auto' -> 0  或  backup_type='Manual' -> 1
            now = datetime.datetime.now()
            begin_time = now + datetime.timedelta(days=begin_day)
            params = {
                'Action': 'DescribeUDBBackup',          # 接口名称
                'Region': self.region,                  # 地区
                'ProjectId': self.project_id,
                'PublicKey': self.PublicKey,
                'DBId': db_id,
                'Limit': 100,
                'Offset': 0,
                'BackupType': backup_type_int,
                'BeginTime': int(time.mktime(begin_time.timetuple())),          # 过滤条件:起始时间(Unix时间戳)
                'EndTime': int(time.mktime(now.timetuple())),                   # 过滤条件:结束时间(Unix时间戳)
            }
            # 签名
            signature = verify_ac(self.PublicKey, self.PrivateKey, params)
            params['Signature'] = signature

            # POST请求接口
            headers = {'Content-Type': 'application/json'}
            response = requests.post(url=self.api_url, headers=headers, data=json.dumps(params))
            resp_string = response.content.decode('utf-8')

            return resp_string

        except Exception as err:
            # print(err)
            return err



    def describeUDBInstanceBackupURL(self, db_id, backup_id):
        """[获取UDB备份下载地址 - DescribeUDBInstanceBackupURL]https://docs.ucloud.cn/api/udb-api/describe_udb_instance_backup_url

        Args:
            db_id (string, optional): [DB实例Id]
            backup_id (string, optional): [DB实例备份ID]

        Returns:
            [str]: [response]
        """
        try:
            params = {
                'Action': 'DescribeUDBInstanceBackupURL',          # 接口名称
                'Region': self.region,                  # 地区
                'ProjectId': self.project_id,
                'PublicKey': self.PublicKey,
                'DBId': db_id,
                'BackupId': backup_id,
            }
            # 签名
            signature = verify_ac(self.PublicKey, self.PrivateKey, params)
            params['Signature'] = signature

            # POST请求接口
            headers = {'Content-Type': 'application/json'}
            response = requests.post(url=self.api_url, headers=headers, data=json.dumps(params))
            resp_string = response.content.decode('utf-8')

            return resp_string

        except Exception as err:
            # print(err)
            return err



    def describeURedisGroup(self):
        """[查询主备Redis - DescribeURedisGroup]https://docs.ucloud.cn/api/umem-api/describe_uredis_group
        主要用于获取主备版Redis实例id

        Returns:
            [str]: [response]
        """
        try:
            params = {
                'Action': 'DescribeURedisGroup',          # 接口名称
                'Region': self.region,                  # 地区
                'ProjectId': self.project_id,
                'PublicKey': self.PublicKey,
                'Limit': 100,
                'Offset': 0,
            }
            # 签名
            signature = verify_ac(self.PublicKey, self.PrivateKey, params)
            params['Signature'] = signature

            # POST请求接口
            headers = {'Content-Type': 'application/json'}
            response = requests.post(url=self.api_url, headers=headers, data=json.dumps(params))
            resp_string = response.content.decode('utf-8')

            return resp_string

        except Exception as err:
            # print(err)
            return err



    def describeURedisBackup(self, group_id, backup_type='Auto', begin_day=-1):
        """[查询主备redis备份 - DescribeURedisBackup]https://docs.ucloud.cn/api/umem-api/describe_uredis_backup
        主要用于获取主备版Redis实例id对应的备份id

        Args:
            group_id (string, optional): [组的ID（Redis实例id）]
            backup_type (string, optional): [备份类型] 默认值'Auto'，可选值 Manual 手动 Auto 自动。
            begin_day (int, optional): [过滤条件，查询n天前的备份列表] 取值为整型负数。默认值-1，表示昨天，即获取过去的24小时内的备份列表。

        Returns:
            [str]: [response]
        """
        try:
            now = datetime.datetime.now()
            begin_time = now + datetime.timedelta(days=begin_day)
            now_timestamp = int(time.mktime(now.timetuple()))
            begin_time_timestamp = int(time.mktime(begin_time.timetuple()))
            params = {
                'Action': 'DescribeURedisBackup',       # 接口名称
                'Region': self.region,                  # 地区
                'ProjectId': self.project_id,
                'PublicKey': self.PublicKey,
                'GroupId': group_id,
                'Limit': 100,
                'Offset': 0,
            }
            # 签名
            signature = verify_ac(self.PublicKey, self.PrivateKey, params)
            params['Signature'] = signature

            # POST请求接口
            headers = {'Content-Type': 'application/json'}
            response = requests.post(url=self.api_url, headers=headers, data=json.dumps(params))
            resp_string = response.content.decode('utf-8')
            response_dict = json.loads(resp_string)

            # 以时间区间、备份类型为维度缩小查询范围
            response_dict_new = {
                'RetCode': response_dict['RetCode'],
                'Action': response_dict['Action'],
                'DataSet': [],
            }
            if response_dict['RetCode'] == 0:
                for item in response_dict['DataSet']:
                    if begin_time_timestamp < item['BackupTime'] < now_timestamp and item['BackupType'] == backup_type:
                        response_dict_new['DataSet'].append(item)
            
            response_dict_new['TotalCount'] = len(response_dict_new['DataSet'])
            return json.dumps(response_dict_new)

        except Exception as err:
            # print(err)
            return err



    def describeURedisBackupURL(self, backup_id, zone):
        """[获取主备Redis备份下载链接 - DescribeURedisBackupURL]https://docs.ucloud.cn/api/umem-api/describe_uredis_backup_url

        Args:
            backup_id (string, optional): [备份ID]

        Returns:
            [str]: [response]
        """
        try:
            params = {
                'Action': 'DescribeURedisBackupURL',          # 接口名称
                'Region': self.region,                  # 地区
                'ProjectId': self.project_id,
                'PublicKey': self.PublicKey,
                'Zone': zone,
                'BackupId': backup_id,
            }
            # 签名
            signature = verify_ac(self.PublicKey, self.PrivateKey, params)
            params['Signature'] = signature

            # POST请求接口
            headers = {'Content-Type': 'application/json'}
            response = requests.post(url=self.api_url, headers=headers, data=json.dumps(params))
            resp_string = response.content.decode('utf-8')

            return resp_string

        except Exception as err:
            # print(err)
            return err




import json
from tencentcloud.common import credential
from tencentcloud.common.profile.client_profile import ClientProfile
from tencentcloud.common.profile.http_profile import HttpProfile
from tencentcloud.common.exception.tencent_cloud_sdk_exception import TencentCloudSDKException
from tencentcloud.dnspod.v20210323 import dnspod_client, models

# Write by lyc at 2021-12-6

class DNSPOD():
    """[腾讯云Dnspod Python3 SDK方法封装]
    """
    def __init__(self, key) -> None:
        self.SecretId = key['SecretId']             # 公钥
        self.SecretKey = key['SecretKey']           # 私钥
        self.endpoint = 'dnspod.tencentcloudapi.com'      # 接口地址

        # 签名
        self.cred = credential.Credential(self.SecretId, self.SecretKey)
        httpProfile = HttpProfile()
        httpProfile.endpoint = self.endpoint

        clientProfile = ClientProfile()
        clientProfile.httpProfile = httpProfile
        self.client = dnspod_client.DnspodClient(self.cred, "", clientProfile)


    def describeDomainList(self):
        """[获取域名列表]https://cloud.tencent.com/document/api/1427/56172

        Returns:
            [json]: [json response]
        """
        try:
            req = models.DescribeDomainListRequest()
            params = {

            }
            req.from_json_string(json.dumps(params))

            resp = self.client.DescribeDomainList(req)
            # print(resp.to_json_string())
            return resp.to_json_string()

        except TencentCloudSDKException as err:
            # print(err)
            return err




import os
import time

# 功能：目录与文件操作

def scanDir(targetDir):
    """[扫描目标目录] Write by lyc 2021-5-19

    Args:
        targetDir ([str]): [目标目录]

    Yields:
        [dic]: [返回文件的相对路径和绝对路径] 
                file_info = {
                'abs_file_path': ,      # 文件的绝对路径
                'rel_file_path': ,      # 文件的相对路径
                }
    """
    relativePath = targetDir.rsplit(os.sep, 1)[0] + os.sep  # 目标的相对路径
    relativeDir = targetDir.rsplit(os.sep, 1)[-1]  # 目标的相对路径下的第一级目录

    for (dirpath, dirnames, filenames) in os.walk(targetDir):
        for fn in filenames:
            # 把 dirpath 和 每个文件名拼接起来 就是全路径
            abs_file_path = os.path.join(dirpath, fn)  # 文件的绝对路径
            rel_file_path = abs_file_path.replace(relativePath, '')  # 文件的相对路径
            file_info = {
                'abs_file_path': abs_file_path,
                'rel_file_path': rel_file_path,
            }
            yield file_info



def is_expire(file_timestamp, expire_day):
    """[判断一个文件的是否过期]
    
    Args:
        file_timestamp ([string]): [文件的最后修改时间]
        expire_day ([int]): [过期时间，单位day]

    Returns:
        [bool]: [True-文件过期，False-文件未过期]
    """
    now_timestamp = time.time()
    diff_timestamp = now_timestamp - file_timestamp     # 时间差的时间戳
    diff_structtime = time.localtime(diff_timestamp)    # 时间差的结构化时间
    diff_days = (diff_structtime.tm_year - 1970)*365 + \
               (diff_structtime.tm_mon - 1)*30 + \
               (diff_structtime.tm_mday - 1)*1          # 时间差转换成天
    
    return True if diff_days > expire_day else False    # 比较时间差的天数与过期时间


def clean_dir(dir, save_day):
    """[清除目录下过期的文件；生成器函数，每删除成功一个文件返回一条 dict 状态码]
    
    :return: ret_code=1 删除文件成功
    Args:
        dir ([string]): [要清理的目录，绝对路径]
        save_day ([int]): [保存时间]

    Yields:
        [string]: [description]
    """
    try:
        if os.path.exists(dir):
            os.chdir(dir)
            for item in os.listdir(dir):        # 遍历该目录下的所有文件存进列表
                if is_expire(os.path.getmtime(item), int(save_day)):     # 调用比较时间的函数，返回值为True表示已过期
                    os.remove(item)             # 过期则删除
                    filename = dir + os.sep + item
                    yield filename
    
    except Exception as err:
        print(err)

